/***********************************************************************

 SV1Codec RLE compression/decompression
 and various TT savegame format handling routines
 (header file)

 This file is a part of SV1Codec.
 SV1Codec is Copyright (C) 2002 by Marcin Grzegorczyk.
 See sv1codec.c for details.

 The code in this file is explicitly placed in the public domain.
 Use, abuse and redistribute freely.

***********************************************************************/

#ifndef SV1C_RLE_H
#define SV1C_RLE_H

#include "sv1codec.h"

/*
 Prototype of a callback function used by RLE_Decode() and RLE_Encode()
 to write their output. The function is supposed to write 'n' bytes
 of data from the location pointed to by 'ptr' to some buffer or file,
 and return 0 if all bytes were successfully written, or a nonzero
 error code if anything went wrong.
*/
typedef int tRLEWriteResultCallback(const void *ptr, size_t n);

/* Public functions in this module */
PUBLIC_DECLARATION uint16_t CalcTitleChecksum(const unsigned char *titlebuf, size_t buflen);
PUBLIC_DECLARATION void ChksumStep(const unsigned char c, uint32_t *const chksump);
PUBLIC_DECLARATION uint32_t CalcFileChecksum(const unsigned char *data, size_t length, uint32_t adjustment);
PUBLIC_DECLARATION int RLE_Decode(const unsigned char *pSrc, const size_t size, tRLEWriteResultCallback *const write_call);
PUBLIC_DECLARATION int RLE_Encode(const unsigned char *pSrc, const size_t size, tRLEWriteResultCallback *const write_call, uint32_t *const chksump, const int code_min, const int code_max);
PUBLIC_DECLARATION enum eSVVersion DetectTTByTitle(const unsigned char *buf, const size_t len);
PUBLIC_DECLARATION enum eSVVersion DetectTTBySize(long flen);
PUBLIC_DECLARATION int VerifyTTDData(const struct sBufferInfo *const buf, const int ttdp, const unsigned chunks);
PUBLIC_DECLARATION size_t TitleLengthFromVersion(enum eSVVersion sv_v);
PUBLIC_DECLARATION uint32_t ChecksumAdjFromVersion(enum eSVVersion sv_v);
PUBLIC_DECLARATION int GetLandscapeStyle(const struct sBufferInfo *const buf, const int ttdp);
PUBLIC_DECLARATION int GetNumberOfPlayers(const struct sBufferInfo *const buf, enum eSVVersion sv_v, const int ttdp);


#endif /* SV1C_RLE_H */

